==> cellmaps_utils-0.3.0a1.tar.gz: cellmaps_utils-0.3.0a1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""
import os
import re
from setuptools import setup, find_packages


with open(os.path.join('cellmaps_utils', '__init__.py')) as ver_file:
    for line in ver_file:
        line = line.rstrip()
        if line.startswith('__version__'):
            version = re.sub("'", "", line[line.index("'"):])
        elif line.startswith('__description__'):
            desc = re.sub("'", "", line[line.index("'"):])
        elif line.startswith('__repo_url__'):
            repo_url = re.sub("'", "", line[line.index("'"):])
        elif line.startswith('__author__'):
            author = re.sub("'", "", line[line.index("'"):])
        elif line.startswith('__email__'):
            email = re.sub("'", "", line[line.index("'"):])

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()


requirements = ['fairscape-cli==0.2.0',
                'scipy',
                'scikit-learn',
                'pandas',
                'numpy',
                'dill',
                'tqdm']

setup_requirements = [ ]

test_requirements = [ ]

setup(
    author=author,
    author_email=email,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11'
    ],
    description=desc,
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    long_description_content_type='text/x-rst',
    include_package_data=True,
    keywords='cellmaps_utils',
    name='cellmaps_utils',
    packages=find_packages(include=['cellmaps_utils']),
    package_dir={'cellmaps_utils': 'cellmaps_utils'},
    package_data={'cellmaps_utils': ['apms_readme.txt',
                                     'crispr_readme.txt',
                                     'ifimage_readme.txt']},
    scripts=['cellmaps_utils/cellmaps_utilscmd.py'],
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url=repo_url,
    version=version,
    zip_safe=False)

==> cellmaps_utils-0.4.0.tar.gz: cellmaps_utils-0.4.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""
import os
import re
from setuptools import setup, find_packages


with open(os.path.join('cellmaps_utils', '__init__.py')) as ver_file:
    for line in ver_file:
        line = line.rstrip()
        if line.startswith('__version__'):
            version = re.sub("'", "", line[line.index("'"):])
        elif line.startswith('__description__'):
            desc = re.sub("'", "", line[line.index("'"):])
        elif line.startswith('__repo_url__'):
            repo_url = re.sub("'", "", line[line.index("'"):])
        elif line.startswith('__author__'):
            author = re.sub("'", "", line[line.index("'"):])
        elif line.startswith('__email__'):
            email = re.sub("'", "", line[line.index("'"):])

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()


requirements = ['fairscape-cli==0.2.0',
                'ndex2>=3.8.0,<4.0.0',
                'scipy',
                'scikit-learn',
                'pandas',
                'numpy',
                'dill',
                'tqdm',
                'requests']

setup_requirements = [ ]

test_requirements = ['requests_mock']

setup(
    author=author,
    author_email=email,
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11'
    ],
    description=desc,
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    long_description_content_type='text/x-rst',
    include_package_data=True,
    keywords='cellmaps_utils',
    name='cellmaps_utils',
    packages=find_packages(include=['cellmaps_utils']),
    package_dir={'cellmaps_utils': 'cellmaps_utils'},
    package_data={'cellmaps_utils': ['apms_readme.txt',
                                     'crispr_readme.txt',
                                     'ifimage_readme.txt']},
    scripts=['cellmaps_utils/cellmaps_utilscmd.py'],
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url=repo_url,
    version=version,
    zip_safe=False)
